@@ -1,6 +1,8 @@
 __author__ = 'Lene Preuss <lene.preuss@gmail.com>'
 
 import logging
+from argparse import Namespace
+from dataclasses import dataclass
 from multiprocessing.pool import ThreadPool as Pool
 from pathlib import Path
 from typing import Dict, List, Iterator, Optional
@@ -9,32 +11,44 @@ from PIL import Image
 
 from duplicate_images.common import path_with_parent
 from duplicate_images.function_types import Cache, CacheEntry, HashFunction, ImagePair, Results
-from duplicate_images.parallel_options import ParallelOptions
 from duplicate_images.progress_bar_manager import ProgressBarManager
 
 
+@dataclass(frozen=True)
+class PairFinderOptions:
+    max_distance: int = 0
+    show_progress_bars: bool = False
+    parallel: bool = False
+
+    @classmethod
+    def from_args(cls, args: Namespace):
+        return cls(args.max_distance, args.progress, args.parallel)
+
+
 class ImagePairFinder:
 
     @classmethod
-    def create(  # pylint: disable = too-many-arguments
+    def create(
             cls, files: List[Path], hash_algorithm: HashFunction,
-            parallel_options: ParallelOptions, show_progress_bar: bool = False,
+            options: PairFinderOptions = PairFinderOptions(),
             hash_store: Optional[Cache] = None
     ) -> 'ImagePairFinder':
-        if parallel_options.parallel:
+        if options.parallel:
             return ParallelImagePairFinder(
-                files, hash_algorithm, parallel_options, show_progress_bar, hash_store
+                files, hash_algorithm, options=options, hash_store=hash_store
             )
-        return ImagePairFinder(files, hash_algorithm, show_progress_bar, hash_store)
+        return ImagePairFinder(files, hash_algorithm, options=options, hash_store=hash_store)
 
-    def __init__(
-            self, files: List[Path], hash_algorithm: HashFunction, show_progress_bar: bool = False,
+    def __init__(  # pylint: disable = too-many-arguments
+            self, files: List[Path], hash_algorithm: HashFunction,
+            options: PairFinderOptions = PairFinderOptions(),
             hash_store: Optional[Cache] = None
     ) -> None:
         self.files = files
         self.algorithm = hash_algorithm
+        self.max_distance = options.max_distance
         self.hash_store = hash_store if hash_store is not None else {}
-        self.progress_bars = ProgressBarManager.create(len(files), show_progress_bar)
+        self.progress_bars = ProgressBarManager.create(len(files), options.show_progress_bars)
         self.precalculated_hashes = self.get_hashes(files)
         self.progress_bars.close_reader()
 
@@ -67,7 +81,7 @@ class ImagePairFinder:
         logging.debug(
             "%-30s - %-30s = %d", file.stem, other_file.stem, hash_distance
         )
-        return hash_distance == 0
+        return hash_distance <= self.max_distance
 
     def get_hash(self, file: Path) -> CacheEntry:
         self.progress_bars.update_reader()
@@ -91,14 +105,6 @@ class ImagePairFinder:
 
 
 class ParallelImagePairFinder(ImagePairFinder):
-    def __init__(  # pylint: disable = too-many-arguments
-            self, files: List[Path], hash_algorithm: HashFunction,
-            parallel_options: ParallelOptions, show_progress_bar: bool = False,
-            hash_store: Optional[Cache] = None
-    ):
-        self.parallel_options = parallel_options
-        super().__init__(files, hash_algorithm, show_progress_bar, hash_store)
-
     def precalculate_hashes(self, image_files: List[Path]) -> List[CacheEntry]:
         with Pool() as pool:
             return pool.map(self.get_hash, image_files)
@@ -112,10 +118,12 @@ class ParallelFilteringImagePairFinder(ParallelImagePairFinder):
     parallel one day. In that case ImagePairFinder.create() needs to return a
     ParallelFilteringImagePairFinder to utilize it.
     """
+    CHUNK_SIZE = 100
+
     def filter_matches(self, all_pairs: Iterator[ImagePair]) -> Results:
         pairs = list(all_pairs)
         with Pool() as pool:
             to_keep = pool.starmap(
-                self.are_images_equal, pairs, chunksize=self.parallel_options.chunk_size
+                self.are_images_equal, pairs, chunksize=self.CHUNK_SIZE
             )
         return [c for c, keep in zip(pairs, to_keep) if keep]
