@@ -17,9 +17,13 @@ def parse_command_line() -> Namespace:
         default='phash',
         help="Method used to determine if two images are considered equal"
     )
+    parser.add_argument(
+        '--max-distance', type=int, default=0,
+        help="Maximum hash distance for images to be considered equal"
+    )
     parser.add_argument(
         '--on-equal', choices=ACTIONS_ON_EQUALITY.keys(),
-        default='print', help="command to be run on each pair of images found to be equal"
+        default='print', help="Command to be run on each pair of images found to be equal"
     )
     parser.add_argument(
         '--parallel', action='store_true', help="Filter using all available cores (Experimental)"
@@ -30,6 +34,9 @@ def parse_command_line() -> Namespace:
     parser.add_argument(
         '--debug', action='store_true', help="Print lots of debugging info"
     )
+    parser.add_argument(
+        '--quiet', '-q', action='count', default=0, help="Decrease log level by one for each"
+    )
     parser.add_argument(
         '--hash-db', default=None, help="File storing precomputed hashes"
     )
